package io.dcloud.feature.weex.adapter.webview;

import android.content.Context;
import android.content.Intent;
import android.net.Uri;
import android.text.TextUtils;
import android.view.View;
import androidx.annotation.NonNull;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.taobao.weex.WXSDKInstance;
import com.taobao.weex.WXSDKManager;
import com.taobao.weex.annotation.Component;
import com.taobao.weex.annotation.JSMethod;
import com.taobao.weex.ui.action.BasicComponentData;
import com.taobao.weex.ui.component.WXComponentProp;
import com.taobao.weex.ui.component.WXVContainer;
import com.taobao.weex.ui.component.WXWeb;
import com.taobao.weex.ui.view.IWebView;
import com.taobao.weex.ui.view.IWebView.OnErrorListener;
import com.taobao.weex.ui.view.IWebView.OnMessageListener;
import com.taobao.weex.ui.view.IWebView.OnPageListener;
import com.taobao.weex.utils.WXResourceUtils;
import io.dcloud.common.DHInterface.IWebview;
import io.dcloud.common.adapter.ui.AdaWebview;
import io.dcloud.common.adapter.ui.webview.WebViewFactory;
import io.dcloud.common.adapter.util.PlatformUtil;
import io.dcloud.feature.weex.WeexInstanceMgr;
import io.dcloud.feature.weex.adapter.webview.DCWXWebView;
import io.dcloud.feature.weex.adapter.webview.IDCWebView;
import java.util.HashMap;
import java.util.Map;

@Component(
   lazyload = false
)
public class WXDCWeb extends WXWeb {

   private JSONObject mWebStyles;
   IDCWebView mDCWebView;


   public WXDCWeb(WXSDKInstance instance, WXVContainer parent, boolean isLazy, BasicComponentData basicComponentData) {
      super(instance, parent, isLazy, basicComponentData);
   }

   protected void createWebView() {
      String origin = null;

      try {
         String ob = WXSDKManager.getInstance().getSDKInstance(this.getInstanceId()).getBundleUrl();
         Uri uri = Uri.parse(ob);
         String scheme = uri.getScheme();
         String authority = uri.getAuthority();
         if(!TextUtils.isEmpty(scheme) && !TextUtils.isEmpty(authority)) {
            origin = scheme + "://" + authority;
         }
      } catch (Exception var6) {
         ;
      }

      if(WebViewFactory.isIsOtherInitSuccess()) {
         Object ob1 = PlatformUtil.newInstance("io.dcloud.feature.x5.DCWXX5WebView", new Class[]{Context.class, String.class, WXDCWeb.class}, new Object[]{this.getInstance().getUIContext(), origin, this});
         if(ob1 != null && ob1 instanceof IWebView) {
            this.mDCWebView = (IDCWebView)ob1;
            this.mWebView = this.mDCWebView;
         }
      }

      if(this.mWebView == null) {
         this.mDCWebView = new DCWXWebView(this.getInstance().getUIContext(), origin, this);
         this.mWebView = this.mDCWebView;
      }

   }

   protected View initComponentHostView(@NonNull Context context) {
      WXDCWeb.OnDCMessageListener listener = new WXDCWeb.OnDCMessageListener() {
         public void onMessage(Map params, int type) {
            switch(type) {
            case 1:
               WXDCWeb.this.fireEvent("onPostMessage", params);
               break;
            case 2:
               WXSDKInstance instance = WeexInstanceMgr.self().findWXSDKInstance("__uniapp__service");
               if(instance != null) {
                  params.put("ref", WXDCWeb.this.getRef());
                  params.put("id", WXDCWeb.this.getInstance().getInstanceId());
                  instance.fireGlobalEventCallback("WebviewPostMessage", params);
               }
            }

         }
      };
      PlatformUtil.invokeMethod(this.mWebView, "setOnDCMessageListener", new Class[]{WXDCWeb.OnDCMessageListener.class}, new Object[]{listener});
      this.mWebView.setOnErrorListener(new OnErrorListener() {
         public void onError(String type, Object message) {
            WXDCWeb.this.fireEvent(type, message);
         }
      });
      this.mWebView.setOnPageListener(new OnPageListener() {
         public void onReceivedTitle(String title) {
            if(WXDCWeb.this.getEvents().contains("receivedtitle")) {
               HashMap params = new HashMap();
               params.put("title", title);
               HashMap detail = new HashMap();
               detail.put("detail", params);
               WXDCWeb.this.fireEvent("receivedtitle", detail);
            }

         }
         public void onPageStart(String url) {
            if(WXDCWeb.this.getEvents().contains("pagestart")) {
               HashMap params = new HashMap();
               params.put("url", url);
               HashMap detail = new HashMap();
               detail.put("detail", params);
               WXDCWeb.this.fireEvent("pagestart", detail);
            }

         }
         public void onPageFinish(String url, boolean canGoBack, boolean canGoForward) {
            if(WXDCWeb.this.getEvents().contains("pagefinish")) {
               HashMap params = new HashMap();
               params.put("url", url);
               params.put("canGoBack", Boolean.valueOf(canGoBack));
               params.put("canGoForward", Boolean.valueOf(canGoForward));
               HashMap detail = new HashMap();
               detail.put("detail", params);
               WXDCWeb.this.fireEvent("pagefinish", detail);
            }

         }
      });
      this.mWebView.setOnMessageListener(new OnMessageListener() {
         public void onMessage(Map params) {
            HashMap detail = new HashMap();
            detail.put("detail", params);
            WXDCWeb.this.fireEvent("message", detail);
         }
      });
      View view = this.mWebView.getView();
      if(!TextUtils.isEmpty(AdaWebview.sCustomUserAgent)) {
         this.mDCWebView.setUserAgent(AdaWebview.sCustomUserAgent, true);
      } else {
         IWebview iWebview = WeexInstanceMgr.self().findWebview(this.getInstance());
         if(iWebview != null) {
            String customeUA = iWebview.obtainApp().obtainConfigProperty("useragent");
            boolean concatenate = Boolean.parseBoolean(iWebview.obtainApp().obtainConfigProperty("concatenate"));
            this.mDCWebView.setUserAgent(customeUA, !concatenate);
         }
      }

      return view;
   }

   private void fireEvent(String type, Object message) {
      if(this.getEvents().contains("error")) {
         HashMap params = new HashMap();
         params.put("type", type);
         params.put("errorMsg", message);
         HashMap detail = new HashMap();
         detail.put("detail", params);
         this.fireEvent("error", detail);
      }

   }

   @JSMethod
   public void evalJs(String js) {
      if(this.mWebView != null) {
         String jsp = "javascript:(function(){";
         if(!js.startsWith(jsp)) {
            js = jsp + js + ";})();";
         }

         this.mWebView.loadUrl(js);
      }

   }

   @JSMethod
   public void evalJS(String js) {
      this.evalJs(js);
   }

   protected void loadUrl(String url) {
      if(!TextUtils.isEmpty(url) && url.startsWith("asset:///")) {
         url = url.replace("asset:///", "file:///android_asset/");
      }

      super.loadUrl(url);
   }

   public void onActivityResult(int requestCode, int resultCode, Intent data) {
      if(this.mWebView != null) {
         this.mWebView.onActivityResult(requestCode, resultCode, data);
      }

   }

   @WXComponentProp(
      name = "webviewStyles"
   )
   public void webviewStyles(String styles) {
      if(this.mWebStyles == null) {
         this.mWebStyles = new JSONObject();
      }

      JSONObject object = JSON.parseObject(styles);
      if(object != null && object.containsKey("progress")) {
         Object v = object.get("progress");
         if(v instanceof Boolean) {
            this.mWebStyles.put("isProgress", Boolean.valueOf(((Boolean)v).booleanValue()));
         } else if(v instanceof JSONObject) {
            JSONObject sj = (JSONObject)v;
            this.mWebStyles.put("isProgress", Boolean.valueOf(true));
            if(sj.containsKey("color")) {
               this.mWebStyles.put("progressColor", sj.getString("color"));
            }
         }
      }

   }

   public JSONObject getWebStyles() {
      if(this.mWebStyles == null) {
         this.mWebStyles = new JSONObject();
         this.mWebStyles.put("isProgress", Boolean.valueOf(true));
      }

      return this.mWebStyles;
   }

   public void setBackgroundColor(String color) {
      super.setBackgroundColor(color);
      if(!TextUtils.isEmpty(color) && this.mDCWebView != null) {
         int colorInt = WXResourceUtils.getColor(color);
         if(this.mDCWebView.getWebView() != null) {
            this.mDCWebView.getWebView().setBackgroundColor(colorInt);
         }
      }

   }

   public void destroy() {
      super.destroy();
      this.mDCWebView = null;
   }

   public interface OnDCMessageListener {

      void onMessage(Map var1, int var2);
   }
}
